from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.HumanInterfaceDevice
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class HidBooleanControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidBooleanControl'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl) -> UInt32: ...
    @winrt_mixinmethod
    def get_UsagePage(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl) -> UInt16: ...
    @winrt_mixinmethod
    def get_UsageId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl) -> UInt16: ...
    @winrt_mixinmethod
    def get_IsActive(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActive(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ControlDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControl) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription: ...
    ControlDescription = property(get_ControlDescription, None)
    Id = property(get_Id, None)
    IsActive = property(get_IsActive, put_IsActive)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class HidBooleanControlDescription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription) -> UInt32: ...
    @winrt_mixinmethod
    def get_ReportId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription) -> UInt16: ...
    @winrt_mixinmethod
    def get_ReportType(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidReportType: ...
    @winrt_mixinmethod
    def get_UsagePage(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription) -> UInt16: ...
    @winrt_mixinmethod
    def get_UsageId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription) -> UInt16: ...
    @winrt_mixinmethod
    def get_ParentCollections(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidCollection]: ...
    @winrt_mixinmethod
    def get_IsAbsolute(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription2) -> Boolean: ...
    Id = property(get_Id, None)
    IsAbsolute = property(get_IsAbsolute, None)
    ParentCollections = property(get_ParentCollections, None)
    ReportId = property(get_ReportId, None)
    ReportType = property(get_ReportType, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class HidCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidCollection
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidCollection'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidCollection) -> UInt32: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidCollection) -> win32more.Windows.Devices.HumanInterfaceDevice.HidCollectionType: ...
    @winrt_mixinmethod
    def get_UsagePage(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidCollection) -> UInt32: ...
    @winrt_mixinmethod
    def get_UsageId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidCollection) -> UInt32: ...
    Id = property(get_Id, None)
    Type = property(get_Type, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class HidCollectionType(Enum, Int32):
    Physical = 0
    Application = 1
    Logical = 2
    Report = 3
    NamedArray = 4
    UsageSwitch = 5
    UsageModifier = 6
    Other = 7
class HidDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidDevice'
    @winrt_mixinmethod
    def get_VendorId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> UInt16: ...
    @winrt_mixinmethod
    def get_ProductId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> UInt16: ...
    @winrt_mixinmethod
    def get_Version(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> UInt16: ...
    @winrt_mixinmethod
    def get_UsagePage(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> UInt16: ...
    @winrt_mixinmethod
    def get_UsageId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> UInt16: ...
    @winrt_mixinmethod
    def GetInputReportAsync(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidInputReport]: ...
    @winrt_mixinmethod
    def GetInputReportByIdAsync(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportId: UInt16) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidInputReport]: ...
    @winrt_mixinmethod
    def GetFeatureReportAsync(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport]: ...
    @winrt_mixinmethod
    def GetFeatureReportByIdAsync(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportId: UInt16) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport]: ...
    @winrt_mixinmethod
    def CreateOutputReport(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> win32more.Windows.Devices.HumanInterfaceDevice.HidOutputReport: ...
    @winrt_mixinmethod
    def CreateOutputReportById(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidOutputReport: ...
    @winrt_mixinmethod
    def CreateFeatureReport(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice) -> win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport: ...
    @winrt_mixinmethod
    def CreateFeatureReportById(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport: ...
    @winrt_mixinmethod
    def SendOutputReportAsync(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, outputReport: win32more.Windows.Devices.HumanInterfaceDevice.HidOutputReport) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
    @winrt_mixinmethod
    def SendFeatureReportAsync(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, featureReport: win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
    @winrt_mixinmethod
    def GetBooleanControlDescriptions(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportType: win32more.Windows.Devices.HumanInterfaceDevice.HidReportType, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription]: ...
    @winrt_mixinmethod
    def GetNumericControlDescriptions(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportType: win32more.Windows.Devices.HumanInterfaceDevice.HidReportType, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription]: ...
    @winrt_mixinmethod
    def add_InputReportReceived(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, reportHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.HumanInterfaceDevice.HidDevice, win32more.Windows.Devices.HumanInterfaceDevice.HidInputReportReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_InputReportReceived(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidDevice, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.HumanInterfaceDevice.IHidDeviceStatics, usagePage: UInt16, usageId: UInt16) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorVidPid(cls: win32more.Windows.Devices.HumanInterfaceDevice.IHidDeviceStatics, usagePage: UInt16, usageId: UInt16, vendorId: UInt16, productId: UInt16) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.HumanInterfaceDevice.IHidDeviceStatics, deviceId: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidDevice]: ...
    ProductId = property(get_ProductId, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
    VendorId = property(get_VendorId, None)
    Version = property(get_Version, None)
    InputReportReceived = event()
class HidFeatureReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidFeatureReport'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport) -> UInt16: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def GetBooleanControl(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_mixinmethod
    def GetBooleanControlByDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_mixinmethod
    def GetNumericControl(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    @winrt_mixinmethod
    def GetNumericControlByDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidFeatureReport, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    Data = property(get_Data, put_Data)
    Id = property(get_Id, None)
class HidInputReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidInputReport'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport) -> UInt16: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def get_ActivatedBooleanControls(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl]: ...
    @winrt_mixinmethod
    def get_TransitionedBooleanControls(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl]: ...
    @winrt_mixinmethod
    def GetBooleanControl(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_mixinmethod
    def GetBooleanControlByDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_mixinmethod
    def GetNumericControl(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    @winrt_mixinmethod
    def GetNumericControlByDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReport, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    ActivatedBooleanControls = property(get_ActivatedBooleanControls, None)
    Data = property(get_Data, None)
    Id = property(get_Id, None)
    TransitionedBooleanControls = property(get_TransitionedBooleanControls, None)
class HidInputReportReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReportReceivedEventArgs
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidInputReportReceivedEventArgs'
    @winrt_mixinmethod
    def get_Report(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidInputReportReceivedEventArgs) -> win32more.Windows.Devices.HumanInterfaceDevice.HidInputReport: ...
    Report = property(get_Report, None)
class HidNumericControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidNumericControl'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> UInt32: ...
    @winrt_mixinmethod
    def get_IsGrouped(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> Boolean: ...
    @winrt_mixinmethod
    def get_UsagePage(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> UInt16: ...
    @winrt_mixinmethod
    def get_UsageId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> UInt16: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> Int64: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl, value: Int64) -> Void: ...
    @winrt_mixinmethod
    def get_ScaledValue(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> Int64: ...
    @winrt_mixinmethod
    def put_ScaledValue(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl, value: Int64) -> Void: ...
    @winrt_mixinmethod
    def get_ControlDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControl) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription: ...
    ControlDescription = property(get_ControlDescription, None)
    Id = property(get_Id, None)
    IsGrouped = property(get_IsGrouped, None)
    ScaledValue = property(get_ScaledValue, put_ScaledValue)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
    Value = property(get_Value, put_Value)
class HidNumericControlDescription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt32: ...
    @winrt_mixinmethod
    def get_ReportId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt16: ...
    @winrt_mixinmethod
    def get_ReportType(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidReportType: ...
    @winrt_mixinmethod
    def get_ReportSize(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt32: ...
    @winrt_mixinmethod
    def get_ReportCount(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt32: ...
    @winrt_mixinmethod
    def get_UsagePage(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt16: ...
    @winrt_mixinmethod
    def get_UsageId(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt16: ...
    @winrt_mixinmethod
    def get_LogicalMinimum(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> Int32: ...
    @winrt_mixinmethod
    def get_LogicalMaximum(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> Int32: ...
    @winrt_mixinmethod
    def get_PhysicalMinimum(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> Int32: ...
    @winrt_mixinmethod
    def get_PhysicalMaximum(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> Int32: ...
    @winrt_mixinmethod
    def get_UnitExponent(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt32: ...
    @winrt_mixinmethod
    def get_Unit(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> UInt32: ...
    @winrt_mixinmethod
    def get_IsAbsolute(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> Boolean: ...
    @winrt_mixinmethod
    def get_HasNull(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> Boolean: ...
    @winrt_mixinmethod
    def get_ParentCollections(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidCollection]: ...
    HasNull = property(get_HasNull, None)
    Id = property(get_Id, None)
    IsAbsolute = property(get_IsAbsolute, None)
    LogicalMaximum = property(get_LogicalMaximum, None)
    LogicalMinimum = property(get_LogicalMinimum, None)
    ParentCollections = property(get_ParentCollections, None)
    PhysicalMaximum = property(get_PhysicalMaximum, None)
    PhysicalMinimum = property(get_PhysicalMinimum, None)
    ReportCount = property(get_ReportCount, None)
    ReportId = property(get_ReportId, None)
    ReportSize = property(get_ReportSize, None)
    ReportType = property(get_ReportType, None)
    Unit = property(get_Unit, None)
    UnitExponent = property(get_UnitExponent, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class HidOutputReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.HidOutputReport'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport) -> UInt16: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def GetBooleanControl(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_mixinmethod
    def GetBooleanControlByDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_mixinmethod
    def GetNumericControl(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    @winrt_mixinmethod
    def GetNumericControlByDescription(self: win32more.Windows.Devices.HumanInterfaceDevice.IHidOutputReport, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    Data = property(get_Data, put_Data)
    Id = property(get_Id, None)
class HidReportType(Enum, Int32):
    Input = 0
    Output = 1
    Feature = 2
class IHidBooleanControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidBooleanControl'
    _iid_ = Guid('{524df48a-3695-408c-bba2-e2eb5abfbc20}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_UsagePage(self) -> UInt16: ...
    @winrt_commethod(8)
    def get_UsageId(self) -> UInt16: ...
    @winrt_commethod(9)
    def get_IsActive(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsActive(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_ControlDescription(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription: ...
    ControlDescription = property(get_ControlDescription, None)
    Id = property(get_Id, None)
    IsActive = property(get_IsActive, put_IsActive)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class IHidBooleanControlDescription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription'
    _iid_ = Guid('{6196e543-29d8-4a2a-8683-849e207bbe31}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_ReportId(self) -> UInt16: ...
    @winrt_commethod(8)
    def get_ReportType(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidReportType: ...
    @winrt_commethod(9)
    def get_UsagePage(self) -> UInt16: ...
    @winrt_commethod(10)
    def get_UsageId(self) -> UInt16: ...
    @winrt_commethod(11)
    def get_ParentCollections(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidCollection]: ...
    Id = property(get_Id, None)
    ParentCollections = property(get_ParentCollections, None)
    ReportId = property(get_ReportId, None)
    ReportType = property(get_ReportType, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class IHidBooleanControlDescription2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidBooleanControlDescription2'
    _iid_ = Guid('{c8eed2ea-8a77-4c36-aa00-5ff0449d3e73}')
    @winrt_commethod(6)
    def get_IsAbsolute(self) -> Boolean: ...
    IsAbsolute = property(get_IsAbsolute, None)
class IHidCollection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidCollection'
    _iid_ = Guid('{7189f5a3-32f1-46e3-befd-44d2663b7e6a}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_Type(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidCollectionType: ...
    @winrt_commethod(8)
    def get_UsagePage(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_UsageId(self) -> UInt32: ...
    Id = property(get_Id, None)
    Type = property(get_Type, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class IHidDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidDevice'
    _iid_ = Guid('{5f8a14e7-2200-432e-95da-d09b87d574a8}')
    @winrt_commethod(6)
    def get_VendorId(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_ProductId(self) -> UInt16: ...
    @winrt_commethod(8)
    def get_Version(self) -> UInt16: ...
    @winrt_commethod(9)
    def get_UsagePage(self) -> UInt16: ...
    @winrt_commethod(10)
    def get_UsageId(self) -> UInt16: ...
    @winrt_commethod(11)
    def GetInputReportAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidInputReport]: ...
    @winrt_commethod(12)
    def GetInputReportByIdAsync(self, reportId: UInt16) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidInputReport]: ...
    @winrt_commethod(13)
    def GetFeatureReportAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport]: ...
    @winrt_commethod(14)
    def GetFeatureReportByIdAsync(self, reportId: UInt16) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport]: ...
    @winrt_commethod(15)
    def CreateOutputReport(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidOutputReport: ...
    @winrt_commethod(16)
    def CreateOutputReportById(self, reportId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidOutputReport: ...
    @winrt_commethod(17)
    def CreateFeatureReport(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport: ...
    @winrt_commethod(18)
    def CreateFeatureReportById(self, reportId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport: ...
    @winrt_commethod(19)
    def SendOutputReportAsync(self, outputReport: win32more.Windows.Devices.HumanInterfaceDevice.HidOutputReport) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
    @winrt_commethod(20)
    def SendFeatureReportAsync(self, featureReport: win32more.Windows.Devices.HumanInterfaceDevice.HidFeatureReport) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
    @winrt_commethod(21)
    def GetBooleanControlDescriptions(self, reportType: win32more.Windows.Devices.HumanInterfaceDevice.HidReportType, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription]: ...
    @winrt_commethod(22)
    def GetNumericControlDescriptions(self, reportType: win32more.Windows.Devices.HumanInterfaceDevice.HidReportType, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription]: ...
    @winrt_commethod(23)
    def add_InputReportReceived(self, reportHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.HumanInterfaceDevice.HidDevice, win32more.Windows.Devices.HumanInterfaceDevice.HidInputReportReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_InputReportReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ProductId = property(get_ProductId, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
    VendorId = property(get_VendorId, None)
    Version = property(get_Version, None)
    InputReportReceived = event()
class IHidDeviceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidDeviceStatics'
    _iid_ = Guid('{9e5981e4-9856-418c-9f73-77de0cd85754}')
    @winrt_commethod(6)
    def GetDeviceSelector(self, usagePage: UInt16, usageId: UInt16) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetDeviceSelectorVidPid(self, usagePage: UInt16, usageId: UInt16, vendorId: UInt16, productId: UInt16) -> WinRT_String: ...
    @winrt_commethod(8)
    def FromIdAsync(self, deviceId: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.HumanInterfaceDevice.HidDevice]: ...
class IHidFeatureReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidFeatureReport'
    _iid_ = Guid('{841d9b79-5ae5-46e3-82ef-1fec5c8942f4}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_Data(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(8)
    def put_Data(self, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(9)
    def GetBooleanControl(self, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_commethod(10)
    def GetBooleanControlByDescription(self, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_commethod(11)
    def GetNumericControl(self, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    @winrt_commethod(12)
    def GetNumericControlByDescription(self, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    Data = property(get_Data, put_Data)
    Id = property(get_Id, None)
class IHidInputReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidInputReport'
    _iid_ = Guid('{c35d0e50-f7e7-4e8d-b23e-cabbe56b90e9}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_Data(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(8)
    def get_ActivatedBooleanControls(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl]: ...
    @winrt_commethod(9)
    def get_TransitionedBooleanControls(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl]: ...
    @winrt_commethod(10)
    def GetBooleanControl(self, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_commethod(11)
    def GetBooleanControlByDescription(self, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_commethod(12)
    def GetNumericControl(self, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    @winrt_commethod(13)
    def GetNumericControlByDescription(self, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    ActivatedBooleanControls = property(get_ActivatedBooleanControls, None)
    Data = property(get_Data, None)
    Id = property(get_Id, None)
    TransitionedBooleanControls = property(get_TransitionedBooleanControls, None)
class IHidInputReportReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidInputReportReceivedEventArgs'
    _iid_ = Guid('{7059c5cb-59b2-4dc2-985c-0adc6136fa2d}')
    @winrt_commethod(6)
    def get_Report(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidInputReport: ...
    Report = property(get_Report, None)
class IHidNumericControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidNumericControl'
    _iid_ = Guid('{e38a12a5-35a7-4b75-89c8-fb1f28b10823}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_IsGrouped(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_UsagePage(self) -> UInt16: ...
    @winrt_commethod(9)
    def get_UsageId(self) -> UInt16: ...
    @winrt_commethod(10)
    def get_Value(self) -> Int64: ...
    @winrt_commethod(11)
    def put_Value(self, value: Int64) -> Void: ...
    @winrt_commethod(12)
    def get_ScaledValue(self) -> Int64: ...
    @winrt_commethod(13)
    def put_ScaledValue(self, value: Int64) -> Void: ...
    @winrt_commethod(14)
    def get_ControlDescription(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription: ...
    ControlDescription = property(get_ControlDescription, None)
    Id = property(get_Id, None)
    IsGrouped = property(get_IsGrouped, None)
    ScaledValue = property(get_ScaledValue, put_ScaledValue)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
    Value = property(get_Value, put_Value)
class IHidNumericControlDescription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidNumericControlDescription'
    _iid_ = Guid('{638d5e86-1d97-4c75-927f-5ff58ba05e32}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_ReportId(self) -> UInt16: ...
    @winrt_commethod(8)
    def get_ReportType(self) -> win32more.Windows.Devices.HumanInterfaceDevice.HidReportType: ...
    @winrt_commethod(9)
    def get_ReportSize(self) -> UInt32: ...
    @winrt_commethod(10)
    def get_ReportCount(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_UsagePage(self) -> UInt16: ...
    @winrt_commethod(12)
    def get_UsageId(self) -> UInt16: ...
    @winrt_commethod(13)
    def get_LogicalMinimum(self) -> Int32: ...
    @winrt_commethod(14)
    def get_LogicalMaximum(self) -> Int32: ...
    @winrt_commethod(15)
    def get_PhysicalMinimum(self) -> Int32: ...
    @winrt_commethod(16)
    def get_PhysicalMaximum(self) -> Int32: ...
    @winrt_commethod(17)
    def get_UnitExponent(self) -> UInt32: ...
    @winrt_commethod(18)
    def get_Unit(self) -> UInt32: ...
    @winrt_commethod(19)
    def get_IsAbsolute(self) -> Boolean: ...
    @winrt_commethod(20)
    def get_HasNull(self) -> Boolean: ...
    @winrt_commethod(21)
    def get_ParentCollections(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.HumanInterfaceDevice.HidCollection]: ...
    HasNull = property(get_HasNull, None)
    Id = property(get_Id, None)
    IsAbsolute = property(get_IsAbsolute, None)
    LogicalMaximum = property(get_LogicalMaximum, None)
    LogicalMinimum = property(get_LogicalMinimum, None)
    ParentCollections = property(get_ParentCollections, None)
    PhysicalMaximum = property(get_PhysicalMaximum, None)
    PhysicalMinimum = property(get_PhysicalMinimum, None)
    ReportCount = property(get_ReportCount, None)
    ReportId = property(get_ReportId, None)
    ReportSize = property(get_ReportSize, None)
    ReportType = property(get_ReportType, None)
    Unit = property(get_Unit, None)
    UnitExponent = property(get_UnitExponent, None)
    UsageId = property(get_UsageId, None)
    UsagePage = property(get_UsagePage, None)
class IHidOutputReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.HumanInterfaceDevice.IHidOutputReport'
    _iid_ = Guid('{62cb2544-c896-4463-93c1-df9db053c450}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt16: ...
    @winrt_commethod(7)
    def get_Data(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(8)
    def put_Data(self, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(9)
    def GetBooleanControl(self, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_commethod(10)
    def GetBooleanControlByDescription(self, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidBooleanControl: ...
    @winrt_commethod(11)
    def GetNumericControl(self, usagePage: UInt16, usageId: UInt16) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    @winrt_commethod(12)
    def GetNumericControlByDescription(self, controlDescription: win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControlDescription) -> win32more.Windows.Devices.HumanInterfaceDevice.HidNumericControl: ...
    Data = property(get_Data, put_Data)
    Id = property(get_Id, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Diagnostics.Debug.ActiveScript
import win32more.Windows.Win32.System.Diagnostics.Debug.WebApp
import win32more.Windows.Win32.Web.MsHtml
class IWebApplicationActivation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bcdcd0de-330e-481b-b843-4898a6a8ebac}')
    @commethod(3)
    def CancelPendingActivation(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebApplicationAuthoringMode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IServiceProvider
    _iid_ = Guid('{720aea93-1964-4db0-b005-29eb9e2b18a9}')
    @commethod(4)
    def get_AuthoringClientBinary(self, designModeDllPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebApplicationHost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cecbd2c3-a3a5-4749-9681-20e9161c6794}')
    @commethod(3)
    def get_HWND(self, hwnd: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_Document(self, htmlDocument: POINTER(win32more.Windows.Win32.Web.MsHtml.IHTMLDocument2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Advise(self, interfaceId: POINTER(Guid), callback: win32more.Windows.Win32.System.Com.IUnknown, cookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Unadvise(self, cookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebApplicationNavigationEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c22615d2-d318-4da2-8422-1fcaf77b10e4}')
    @commethod(3)
    def BeforeNavigate(self, htmlWindow: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, url: win32more.Windows.Win32.Foundation.PWSTR, navigationFlags: UInt32, targetFrameName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def NavigateComplete(self, htmlWindow: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, url: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def NavigateError(self, htmlWindow: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, url: win32more.Windows.Win32.Foundation.PWSTR, targetFrameName: win32more.Windows.Win32.Foundation.PWSTR, statusCode: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DocumentComplete(self, htmlWindow: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, url: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def DownloadBegin(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DownloadComplete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebApplicationScriptEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7c3f6998-1567-4bba-b52b-48d32141d613}')
    @commethod(3)
    def BeforeScriptExecute(self, htmlWindow: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ScriptError(self, htmlWindow: win32more.Windows.Win32.Web.MsHtml.IHTMLWindow2, scriptError: win32more.Windows.Win32.System.Diagnostics.Debug.ActiveScript.IActiveScriptError, url: win32more.Windows.Win32.Foundation.PWSTR, errorHandled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebApplicationUIEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5b2b3f99-328c-41d5-a6f7-7483ed8e71dd}')
    @commethod(3)
    def SecurityProblem(self, securityProblem: UInt32, result: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebApplicationUpdateEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3e59e6b7-c652-4daf-ad5e-16feb350cde3}')
    @commethod(3)
    def OnPaint(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnCssChanged(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def RegisterAuthoringClientFunctionType(authoringModeObject: win32more.Windows.Win32.System.Diagnostics.Debug.WebApp.IWebApplicationAuthoringMode, host: win32more.Windows.Win32.System.Diagnostics.Debug.WebApp.IWebApplicationHost) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def UnregisterAuthoringClientFunctionType(host: win32more.Windows.Win32.System.Diagnostics.Debug.WebApp.IWebApplicationHost) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.Pickers
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class FileExtensionVector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[WinRT_String]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[WinRT_String]
    _classid_ = 'Windows.Storage.Pickers.FileExtensionVector'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], index: UInt32) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], value: WinRT_String, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], index: UInt32, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], index: UInt32, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], startIndex: UInt32, items: FillArray[WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[WinRT_String], items: PassArray[WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.Collections.IIterator[WinRT_String]: ...
    Size = property(get_Size, None)
class FileOpenPicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.IFileOpenPicker
    _classid_ = 'Windows.Storage.Pickers.FileOpenPicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Storage.Pickers.FileOpenPicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Storage.Pickers.FileOpenPicker: ...
    @winrt_mixinmethod
    def get_ContinuationData(self: win32more.Windows.Storage.Pickers.IFileOpenPicker2) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def PickSingleFileAndContinue(self: win32more.Windows.Storage.Pickers.IFileOpenPicker2) -> Void: ...
    @winrt_mixinmethod
    def PickMultipleFilesAndContinue(self: win32more.Windows.Storage.Pickers.IFileOpenPicker2) -> Void: ...
    @winrt_overload
    @winrt_mixinmethod
    def PickSingleFileAsync(self: win32more.Windows.Storage.Pickers.IFileOpenPickerWithOperationId, pickerOperationId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def get_ViewMode(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_mixinmethod
    def put_ViewMode(self: win32more.Windows.Storage.Pickers.IFileOpenPicker, value: win32more.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_mixinmethod
    def get_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.IFileOpenPicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedStartLocation(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_mixinmethod
    def put_SuggestedStartLocation(self: win32more.Windows.Storage.Pickers.IFileOpenPicker, value: win32more.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_mixinmethod
    def get_CommitButtonText(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CommitButtonText(self: win32more.Windows.Storage.Pickers.IFileOpenPicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FileTypeFilter(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @PickSingleFileAsync.register
    @winrt_mixinmethod
    def PickSingleFileAsync(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def PickMultipleFilesAsync(self: win32more.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]]: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Storage.Pickers.IFileOpenPicker3) -> win32more.Windows.System.User: ...
    @winrt_classmethod
    def CreateForUser(cls: win32more.Windows.Storage.Pickers.IFileOpenPickerStatics2, user: win32more.Windows.System.User) -> win32more.Windows.Storage.Pickers.FileOpenPicker: ...
    @winrt_classmethod
    def ResumePickSingleFileAsync(cls: win32more.Windows.Storage.Pickers.IFileOpenPickerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    ContinuationData = property(get_ContinuationData, None)
    FileTypeFilter = property(get_FileTypeFilter, None)
    SettingsIdentifier = property(get_SettingsIdentifier, put_SettingsIdentifier)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    User = property(get_User, None)
    ViewMode = property(get_ViewMode, put_ViewMode)
class FilePickerFileTypesOrderedMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]]
    default_interface: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]
    _classid_ = 'Windows.Storage.Pickers.FilePickerFileTypesOrderedMap'
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]], key: WinRT_String) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]: ...
    @winrt_mixinmethod
    def Insert(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]], key: WinRT_String, value: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> Boolean: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]], key: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]]: ...
    Size = property(get_Size, None)
class FilePickerSelectedFilesArray(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Storage.StorageFile]]
    default_interface: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]
    _classid_ = 'Windows.Storage.Pickers.FilePickerSelectedFilesArray'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile], index: UInt32) -> win32more.Windows.Storage.StorageFile: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile], value: win32more.Windows.Storage.StorageFile, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile], startIndex: UInt32, items: FillArray[win32more.Windows.Storage.StorageFile]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Storage.StorageFile]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Storage.StorageFile]: ...
    Size = property(get_Size, None)
class FileSavePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.IFileSavePicker
    _classid_ = 'Windows.Storage.Pickers.FileSavePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Storage.Pickers.FileSavePicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Storage.Pickers.FileSavePicker: ...
    @winrt_mixinmethod
    def get_ContinuationData(self: win32more.Windows.Storage.Pickers.IFileSavePicker2) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def PickSaveFileAndContinue(self: win32more.Windows.Storage.Pickers.IFileSavePicker2) -> Void: ...
    @winrt_mixinmethod
    def get_EnterpriseId(self: win32more.Windows.Storage.Pickers.IFileSavePicker3) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_EnterpriseId(self: win32more.Windows.Storage.Pickers.IFileSavePicker3, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.IFileSavePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedStartLocation(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_mixinmethod
    def put_SuggestedStartLocation(self: win32more.Windows.Storage.Pickers.IFileSavePicker, value: win32more.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_mixinmethod
    def get_CommitButtonText(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CommitButtonText(self: win32more.Windows.Storage.Pickers.IFileSavePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FileTypeChoices(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]: ...
    @winrt_mixinmethod
    def get_DefaultFileExtension(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DefaultFileExtension(self: win32more.Windows.Storage.Pickers.IFileSavePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedSaveFile(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Windows.Storage.StorageFile: ...
    @winrt_mixinmethod
    def put_SuggestedSaveFile(self: win32more.Windows.Storage.Pickers.IFileSavePicker, value: win32more.Windows.Storage.StorageFile) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedFileName(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SuggestedFileName(self: win32more.Windows.Storage.Pickers.IFileSavePicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def PickSaveFileAsync(self: win32more.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Storage.Pickers.IFileSavePicker4) -> win32more.Windows.System.User: ...
    @winrt_classmethod
    def CreateForUser(cls: win32more.Windows.Storage.Pickers.IFileSavePickerStatics, user: win32more.Windows.System.User) -> win32more.Windows.Storage.Pickers.FileSavePicker: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    ContinuationData = property(get_ContinuationData, None)
    DefaultFileExtension = property(get_DefaultFileExtension, put_DefaultFileExtension)
    EnterpriseId = property(get_EnterpriseId, put_EnterpriseId)
    FileTypeChoices = property(get_FileTypeChoices, None)
    SettingsIdentifier = property(get_SettingsIdentifier, put_SettingsIdentifier)
    SuggestedFileName = property(get_SuggestedFileName, put_SuggestedFileName)
    SuggestedSaveFile = property(get_SuggestedSaveFile, put_SuggestedSaveFile)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    User = property(get_User, None)
class FolderPicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.IFolderPicker
    _classid_ = 'Windows.Storage.Pickers.FolderPicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Storage.Pickers.FolderPicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Storage.Pickers.FolderPicker: ...
    @winrt_mixinmethod
    def get_ContinuationData(self: win32more.Windows.Storage.Pickers.IFolderPicker2) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def PickFolderAndContinue(self: win32more.Windows.Storage.Pickers.IFolderPicker2) -> Void: ...
    @winrt_mixinmethod
    def get_ViewMode(self: win32more.Windows.Storage.Pickers.IFolderPicker) -> win32more.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_mixinmethod
    def put_ViewMode(self: win32more.Windows.Storage.Pickers.IFolderPicker, value: win32more.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_mixinmethod
    def get_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.IFolderPicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.IFolderPicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedStartLocation(self: win32more.Windows.Storage.Pickers.IFolderPicker) -> win32more.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_mixinmethod
    def put_SuggestedStartLocation(self: win32more.Windows.Storage.Pickers.IFolderPicker, value: win32more.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_mixinmethod
    def get_CommitButtonText(self: win32more.Windows.Storage.Pickers.IFolderPicker) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CommitButtonText(self: win32more.Windows.Storage.Pickers.IFolderPicker, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FileTypeFilter(self: win32more.Windows.Storage.Pickers.IFolderPicker) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def PickSingleFolderAsync(self: win32more.Windows.Storage.Pickers.IFolderPicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Storage.Pickers.IFolderPicker3) -> win32more.Windows.System.User: ...
    @winrt_classmethod
    def CreateForUser(cls: win32more.Windows.Storage.Pickers.IFolderPickerStatics, user: win32more.Windows.System.User) -> win32more.Windows.Storage.Pickers.FolderPicker: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    ContinuationData = property(get_ContinuationData, None)
    FileTypeFilter = property(get_FileTypeFilter, None)
    SettingsIdentifier = property(get_SettingsIdentifier, put_SettingsIdentifier)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    User = property(get_User, None)
    ViewMode = property(get_ViewMode, put_ViewMode)
class IFileOpenPicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileOpenPicker'
    _iid_ = Guid('{2ca8278a-12c5-4c5f-8977-94547793c241}')
    @winrt_commethod(6)
    def get_ViewMode(self) -> win32more.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_commethod(7)
    def put_ViewMode(self, value: win32more.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_commethod(8)
    def get_SettingsIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_SettingsIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SuggestedStartLocation(self) -> win32more.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_commethod(11)
    def put_SuggestedStartLocation(self, value: win32more.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_commethod(12)
    def get_CommitButtonText(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_CommitButtonText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_FileTypeFilter(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(15)
    def PickSingleFileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_commethod(16)
    def PickMultipleFilesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    FileTypeFilter = property(get_FileTypeFilter, None)
    SettingsIdentifier = property(get_SettingsIdentifier, put_SettingsIdentifier)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    ViewMode = property(get_ViewMode, put_ViewMode)
class IFileOpenPicker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileOpenPicker2'
    _iid_ = Guid('{8ceb6cd2-b446-46f7-b265-90f8e55ad650}')
    @winrt_commethod(6)
    def get_ContinuationData(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def PickSingleFileAndContinue(self) -> Void: ...
    @winrt_commethod(8)
    def PickMultipleFilesAndContinue(self) -> Void: ...
    ContinuationData = property(get_ContinuationData, None)
class IFileOpenPicker3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileOpenPicker3'
    _iid_ = Guid('{d9a5c5b3-c5dc-5b98-bd80-a8d0ca0584d8}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    User = property(get_User, None)
class IFileOpenPickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileOpenPickerStatics'
    _iid_ = Guid('{6821573b-2f02-4833-96d4-abbfad72b67b}')
    @winrt_commethod(6)
    def ResumePickSingleFileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
class IFileOpenPickerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileOpenPickerStatics2'
    _iid_ = Guid('{e8917415-eddd-5c98-b6f3-366fdfcad392}')
    @winrt_commethod(6)
    def CreateForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Storage.Pickers.FileOpenPicker: ...
class IFileOpenPickerWithOperationId(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileOpenPickerWithOperationId'
    _iid_ = Guid('{3f57b569-2522-4ca5-aa73-a15509f1fcbf}')
    @winrt_commethod(6)
    def PickSingleFileAsync(self, pickerOperationId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
class IFileSavePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileSavePicker'
    _iid_ = Guid('{3286ffcb-617f-4cc5-af6a-b3fdf29ad145}')
    @winrt_commethod(6)
    def get_SettingsIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_SettingsIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_SuggestedStartLocation(self) -> win32more.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_commethod(9)
    def put_SuggestedStartLocation(self, value: win32more.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_commethod(10)
    def get_CommitButtonText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_CommitButtonText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_FileTypeChoices(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Foundation.Collections.IVector[WinRT_String]]: ...
    @winrt_commethod(13)
    def get_DefaultFileExtension(self) -> WinRT_String: ...
    @winrt_commethod(14)
    def put_DefaultFileExtension(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(15)
    def get_SuggestedSaveFile(self) -> win32more.Windows.Storage.StorageFile: ...
    @winrt_commethod(16)
    def put_SuggestedSaveFile(self, value: win32more.Windows.Storage.StorageFile) -> Void: ...
    @winrt_commethod(17)
    def get_SuggestedFileName(self) -> WinRT_String: ...
    @winrt_commethod(18)
    def put_SuggestedFileName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(19)
    def PickSaveFileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    DefaultFileExtension = property(get_DefaultFileExtension, put_DefaultFileExtension)
    FileTypeChoices = property(get_FileTypeChoices, None)
    SettingsIdentifier = property(get_SettingsIdentifier, put_SettingsIdentifier)
    SuggestedFileName = property(get_SuggestedFileName, put_SuggestedFileName)
    SuggestedSaveFile = property(get_SuggestedSaveFile, put_SuggestedSaveFile)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
class IFileSavePicker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileSavePicker2'
    _iid_ = Guid('{0ec313a2-d24b-449a-8197-e89104fd42cc}')
    @winrt_commethod(6)
    def get_ContinuationData(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def PickSaveFileAndContinue(self) -> Void: ...
    ContinuationData = property(get_ContinuationData, None)
class IFileSavePicker3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileSavePicker3'
    _iid_ = Guid('{698aec69-ba3c-4e51-bd90-4abcbbf4cfaf}')
    @winrt_commethod(6)
    def get_EnterpriseId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_EnterpriseId(self, value: WinRT_String) -> Void: ...
    EnterpriseId = property(get_EnterpriseId, put_EnterpriseId)
class IFileSavePicker4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileSavePicker4'
    _iid_ = Guid('{e7d83a5a-ddfa-5de0-8b70-c842c21988ec}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    User = property(get_User, None)
class IFileSavePickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFileSavePickerStatics'
    _iid_ = Guid('{28e3cf9e-961c-5e2c-aed7-e64737f4ce37}')
    @winrt_commethod(6)
    def CreateForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Storage.Pickers.FileSavePicker: ...
class IFolderPicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFolderPicker'
    _iid_ = Guid('{084f7799-f3fb-400a-99b1-7b4a772fd60d}')
    @winrt_commethod(6)
    def get_ViewMode(self) -> win32more.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_commethod(7)
    def put_ViewMode(self, value: win32more.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_commethod(8)
    def get_SettingsIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_SettingsIdentifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SuggestedStartLocation(self) -> win32more.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_commethod(11)
    def put_SuggestedStartLocation(self, value: win32more.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_commethod(12)
    def get_CommitButtonText(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_CommitButtonText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_FileTypeFilter(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(15)
    def PickSingleFolderAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    FileTypeFilter = property(get_FileTypeFilter, None)
    SettingsIdentifier = property(get_SettingsIdentifier, put_SettingsIdentifier)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    ViewMode = property(get_ViewMode, put_ViewMode)
class IFolderPicker2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFolderPicker2'
    _iid_ = Guid('{8eb3ba97-dc85-4616-be94-9660881f2f5d}')
    @winrt_commethod(6)
    def get_ContinuationData(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def PickFolderAndContinue(self) -> Void: ...
    ContinuationData = property(get_ContinuationData, None)
class IFolderPicker3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFolderPicker3'
    _iid_ = Guid('{673b1e29-d326-53c0-bd24-a25c714cee36}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    User = property(get_User, None)
class IFolderPickerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.IFolderPickerStatics'
    _iid_ = Guid('{9be34740-7ca1-5942-a3c8-46f2551ecff3}')
    @winrt_commethod(6)
    def CreateForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Storage.Pickers.FolderPicker: ...
class PickerLocationId(Enum, Int32):
    DocumentsLibrary = 0
    ComputerFolder = 1
    Desktop = 2
    Downloads = 3
    HomeGroup = 4
    MusicLibrary = 5
    PicturesLibrary = 6
    VideosLibrary = 7
    Objects3D = 8
    Unspecified = 9
class PickerViewMode(Enum, Int32):
    List = 0
    Thumbnail = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Data.RightsManagement
import win32more.Windows.Win32.Foundation
DRMHANDLE_INVALID: UInt32 = 0
DRMENVHANDLE_INVALID: UInt32 = 0
DRMQUERYHANDLE_INVALID: UInt32 = 0
DRMHSESSION_INVALID: UInt32 = 0
DRMPUBHANDLE_INVALID: UInt32 = 0
DRM_AL_NONSILENT: UInt32 = 1
DRM_AL_NOPERSIST: UInt32 = 2
DRM_AL_CANCEL: UInt32 = 4
DRM_AL_FETCHNOADVISORY: UInt32 = 8
DRM_AL_NOUI: UInt32 = 16
DRM_ACTIVATE_MACHINE: UInt32 = 1
DRM_ACTIVATE_GROUPIDENTITY: UInt32 = 2
DRM_ACTIVATE_TEMPORARY: UInt32 = 4
DRM_ACTIVATE_CANCEL: UInt32 = 8
DRM_ACTIVATE_SILENT: UInt32 = 16
DRM_ACTIVATE_SHARED_GROUPIDENTITY: UInt32 = 32
DRM_ACTIVATE_DELAYED: UInt32 = 64
DRM_EL_MACHINE: UInt32 = 1
DRM_EL_GROUPIDENTITY: UInt32 = 2
DRM_EL_GROUPIDENTITY_NAME: UInt32 = 4
DRM_EL_GROUPIDENTITY_LID: UInt32 = 8
DRM_EL_SPECIFIED_GROUPIDENTITY: UInt32 = 16
DRM_EL_EUL: UInt32 = 32
DRM_EL_EUL_LID: UInt32 = 64
DRM_EL_CLIENTLICENSOR: UInt32 = 128
DRM_EL_CLIENTLICENSOR_LID: UInt32 = 256
DRM_EL_SPECIFIED_CLIENTLICENSOR: UInt32 = 512
DRM_EL_REVOCATIONLIST: UInt32 = 1024
DRM_EL_REVOCATIONLIST_LID: UInt32 = 2048
DRM_EL_EXPIRED: UInt32 = 4096
DRM_EL_ISSUERNAME: UInt32 = 8192
DRM_EL_ISSUANCELICENSE_TEMPLATE: UInt32 = 16384
DRM_EL_ISSUANCELICENSE_TEMPLATE_LID: UInt32 = 32768
DRM_ADD_LICENSE_NOPERSIST: UInt32 = 0
DRM_ADD_LICENSE_PERSIST: UInt32 = 1
DRM_SERVICE_TYPE_ACTIVATION: UInt32 = 1
DRM_SERVICE_TYPE_CERTIFICATION: UInt32 = 2
DRM_SERVICE_TYPE_PUBLISHING: UInt32 = 4
DRM_SERVICE_TYPE_CLIENTLICENSOR: UInt32 = 8
DRM_SERVICE_TYPE_SILENT: UInt32 = 16
DRM_SERVICE_LOCATION_INTERNET: UInt32 = 1
DRM_SERVICE_LOCATION_ENTERPRISE: UInt32 = 2
DRM_DEFAULTGROUPIDTYPE_WINDOWSAUTH: String = 'WindowsAuthProvider'
DRM_DEFAULTGROUPIDTYPE_PASSPORT: String = 'PassportAuthProvider'
DRM_SIGN_ONLINE: UInt32 = 1
DRM_SIGN_OFFLINE: UInt32 = 2
DRM_SIGN_CANCEL: UInt32 = 4
DRM_SERVER_ISSUANCELICENSE: UInt32 = 8
DRM_AUTO_GENERATE_KEY: UInt32 = 16
DRM_OWNER_LICENSE_NOPERSIST: UInt32 = 32
DRM_REUSE_KEY: UInt32 = 64
DRM_LOCKBOXTYPE_NONE: UInt32 = 0
DRM_LOCKBOXTYPE_WHITEBOX: UInt32 = 1
DRM_LOCKBOXTYPE_BLACKBOX: UInt32 = 2
DRM_LOCKBOXTYPE_DEFAULT: UInt32 = 2
DRM_AILT_NONSILENT: UInt32 = 1
DRM_AILT_OBTAIN_ALL: UInt32 = 2
DRM_AILT_CANCEL: UInt32 = 4
MSDRM_CLIENT_ZONE: UInt32 = 52992
MSDRM_POLICY_ZONE: UInt32 = 37632
DRMIDVERSION: UInt32 = 0
DRMBOUNDLICENSEPARAMSVERSION: UInt32 = 1
DRMBINDINGFLAGS_IGNORE_VALIDITY_INTERVALS: UInt32 = 1
DRMLICENSEACQDATAVERSION: UInt32 = 0
DRMACTSERVINFOVERSION: UInt32 = 0
DRMCLIENTSTRUCTVERSION: UInt32 = 1
DRMCALLBACKVERSION: UInt32 = 1
@winfunctype('msdrm.dll')
def DRMSetGlobalOptions(eGlobalOptions: win32more.Windows.Win32.Data.RightsManagement.DRMGLOBALOPTIONS, pvdata: VoidPtr, dwlen: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetClientVersion(pDRMClientVersionInfo: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRM_CLIENT_VERSION_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMInitEnvironment(eSecurityProviderType: win32more.Windows.Win32.Data.RightsManagement.DRMSECURITYPROVIDERTYPE, eSpecification: win32more.Windows.Win32.Data.RightsManagement.DRMSPECTYPE, wszSecurityProvider: win32more.Windows.Win32.Foundation.PWSTR, wszManifestCredentials: win32more.Windows.Win32.Foundation.PWSTR, wszMachineCredentials: win32more.Windows.Win32.Foundation.PWSTR, phEnv: POINTER(UInt32), phDefaultLibrary: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMLoadLibrary(hEnv: UInt32, eSpecification: win32more.Windows.Win32.Data.RightsManagement.DRMSPECTYPE, wszLibraryProvider: win32more.Windows.Win32.Foundation.PWSTR, wszCredentials: win32more.Windows.Win32.Foundation.PWSTR, phLibrary: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateEnablingPrincipal(hEnv: UInt32, hLibrary: UInt32, wszObject: win32more.Windows.Win32.Foundation.PWSTR, pidPrincipal: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMID), wszCredentials: win32more.Windows.Win32.Foundation.PWSTR, phEnablingPrincipal: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCloseHandle(handle: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCloseEnvironmentHandle(hEnv: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDuplicateHandle(hToCopy: UInt32, phCopy: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDuplicateEnvironmentHandle(hToCopy: UInt32, phCopy: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMRegisterRevocationList(hEnv: UInt32, wszRevocationList: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCheckSecurity(hEnv: UInt32, cLevel: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMRegisterContent(fRegister: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMEncrypt(hCryptoProvider: UInt32, iPosition: UInt32, cNumInBytes: UInt32, pbInData: POINTER(Byte), pcNumOutBytes: POINTER(UInt32), pbOutData: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDecrypt(hCryptoProvider: UInt32, iPosition: UInt32, cNumInBytes: UInt32, pbInData: POINTER(Byte), pcNumOutBytes: POINTER(UInt32), pbOutData: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateBoundLicense(hEnv: UInt32, pParams: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMBOUNDLICENSEPARAMS), wszLicenseChain: win32more.Windows.Win32.Foundation.PWSTR, phBoundLicense: POINTER(UInt32), phErrorLog: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateEnablingBitsDecryptor(hBoundLicense: UInt32, wszRight: win32more.Windows.Win32.Foundation.PWSTR, hAuxLib: UInt32, wszAuxPlug: win32more.Windows.Win32.Foundation.PWSTR, phDecryptor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateEnablingBitsEncryptor(hBoundLicense: UInt32, wszRight: win32more.Windows.Win32.Foundation.PWSTR, hAuxLib: UInt32, wszAuxPlug: win32more.Windows.Win32.Foundation.PWSTR, phEncryptor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMAttest(hEnablingPrincipal: UInt32, wszData: win32more.Windows.Win32.Foundation.PWSTR, eType: win32more.Windows.Win32.Data.RightsManagement.DRMATTESTTYPE, pcAttestedBlob: POINTER(UInt32), wszAttestedBlob: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetTime(hEnv: UInt32, eTimerIdType: win32more.Windows.Win32.Data.RightsManagement.DRMTIMETYPE, poTimeObject: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetInfo(handle: UInt32, wszAttribute: win32more.Windows.Win32.Foundation.PWSTR, peEncoding: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE), pcBuffer: POINTER(UInt32), pbBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetEnvironmentInfo(handle: UInt32, wszAttribute: win32more.Windows.Win32.Foundation.PWSTR, peEncoding: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE), pcBuffer: POINTER(UInt32), pbBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetProcAddress(hLibrary: UInt32, wszProcName: win32more.Windows.Win32.Foundation.PWSTR, ppfnProcAddress: POINTER(win32more.Windows.Win32.Foundation.FARPROC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetBoundLicenseObjectCount(hQueryRoot: UInt32, wszSubObjectType: win32more.Windows.Win32.Foundation.PWSTR, pcSubObjects: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetBoundLicenseObject(hQueryRoot: UInt32, wszSubObjectType: win32more.Windows.Win32.Foundation.PWSTR, iWhich: UInt32, phSubObject: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetBoundLicenseAttributeCount(hQueryRoot: UInt32, wszAttribute: win32more.Windows.Win32.Foundation.PWSTR, pcAttributes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetBoundLicenseAttribute(hQueryRoot: UInt32, wszAttribute: win32more.Windows.Win32.Foundation.PWSTR, iWhich: UInt32, peEncoding: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE), pcBuffer: POINTER(UInt32), pbBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateClientSession(pfnCallback: win32more.Windows.Win32.Data.RightsManagement.DRMCALLBACK, uCallbackVersion: UInt32, wszGroupIDProviderType: win32more.Windows.Win32.Foundation.PWSTR, wszGroupID: win32more.Windows.Win32.Foundation.PWSTR, phClient: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMIsActivated(hClient: UInt32, uFlags: UInt32, pActServInfo: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRM_ACTSERV_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMActivate(hClient: UInt32, uFlags: UInt32, uLangID: UInt32, pActServInfo: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRM_ACTSERV_INFO), pvContext: VoidPtr, hParentWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetServiceLocation(hClient: UInt32, uServiceType: UInt32, uServiceLocation: UInt32, wszIssuanceLicense: win32more.Windows.Win32.Foundation.PWSTR, puServiceURLLength: POINTER(UInt32), wszServiceURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateLicenseStorageSession(hEnv: UInt32, hDefaultLibrary: UInt32, hClient: UInt32, uFlags: UInt32, wszIssuanceLicense: win32more.Windows.Win32.Foundation.PWSTR, phLicenseStorage: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMAddLicense(hLicenseStorage: UInt32, uFlags: UInt32, wszLicense: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMAcquireAdvisories(hLicenseStorage: UInt32, wszLicense: win32more.Windows.Win32.Foundation.PWSTR, wszURL: win32more.Windows.Win32.Foundation.PWSTR, pvContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMEnumerateLicense(hSession: UInt32, uFlags: UInt32, uIndex: UInt32, pfSharedFlag: POINTER(win32more.Windows.Win32.Foundation.BOOL), puCertificateDataLen: POINTER(UInt32), wszCertificateData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMAcquireLicense(hSession: UInt32, uFlags: UInt32, wszGroupIdentityCredential: win32more.Windows.Win32.Foundation.PWSTR, wszRequestedRights: win32more.Windows.Win32.Foundation.PWSTR, wszCustomData: win32more.Windows.Win32.Foundation.PWSTR, wszURL: win32more.Windows.Win32.Foundation.PWSTR, pvContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDeleteLicense(hSession: UInt32, wszLicenseId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCloseSession(hSession: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDuplicateSession(hSessionIn: UInt32, phSessionOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetSecurityProvider(uFlags: UInt32, puTypeLen: POINTER(UInt32), wszType: win32more.Windows.Win32.Foundation.PWSTR, puPathLen: POINTER(UInt32), wszPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMEncode(wszAlgID: win32more.Windows.Win32.Foundation.PWSTR, uDataLen: UInt32, pbDecodedData: POINTER(Byte), puEncodedStringLen: POINTER(UInt32), wszEncodedString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDecode(wszAlgID: win32more.Windows.Win32.Foundation.PWSTR, wszEncodedString: win32more.Windows.Win32.Foundation.PWSTR, puDecodedDataLen: POINTER(UInt32), pbDecodedData: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMConstructCertificateChain(cCertificates: UInt32, rgwszCertificates: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcChain: POINTER(UInt32), wszChain: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMParseUnboundLicense(wszCertificate: win32more.Windows.Win32.Foundation.PWSTR, phQueryRoot: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCloseQueryHandle(hQuery: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUnboundLicenseObjectCount(hQueryRoot: UInt32, wszSubObjectType: win32more.Windows.Win32.Foundation.PWSTR, pcSubObjects: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUnboundLicenseObject(hQueryRoot: UInt32, wszSubObjectType: win32more.Windows.Win32.Foundation.PWSTR, iIndex: UInt32, phSubQuery: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUnboundLicenseAttributeCount(hQueryRoot: UInt32, wszAttributeType: win32more.Windows.Win32.Foundation.PWSTR, pcAttributes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUnboundLicenseAttribute(hQueryRoot: UInt32, wszAttributeType: win32more.Windows.Win32.Foundation.PWSTR, iWhich: UInt32, peEncoding: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE), pcBuffer: POINTER(UInt32), pbBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetCertificateChainCount(wszChain: win32more.Windows.Win32.Foundation.PWSTR, pcCertCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDeconstructCertificateChain(wszChain: win32more.Windows.Win32.Foundation.PWSTR, iWhich: UInt32, pcCert: POINTER(UInt32), wszCert: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMVerify(wszData: win32more.Windows.Win32.Foundation.PWSTR, pcAttestedData: POINTER(UInt32), wszAttestedData: win32more.Windows.Win32.Foundation.PWSTR, peType: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRMATTESTTYPE), pcPrincipal: POINTER(UInt32), wszPrincipal: win32more.Windows.Win32.Foundation.PWSTR, pcManifest: POINTER(UInt32), wszManifest: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateUser(wszUserName: win32more.Windows.Win32.Foundation.PWSTR, wszUserId: win32more.Windows.Win32.Foundation.PWSTR, wszUserIdType: win32more.Windows.Win32.Foundation.PWSTR, phUser: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateRight(wszRightName: win32more.Windows.Win32.Foundation.PWSTR, pstFrom: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), pstUntil: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), cExtendedInfo: UInt32, pwszExtendedInfoName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pwszExtendedInfoValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), phRight: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMCreateIssuanceLicense(pstTimeFrom: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), pstTimeUntil: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), wszReferralInfoName: win32more.Windows.Win32.Foundation.PWSTR, wszReferralInfoURL: win32more.Windows.Win32.Foundation.PWSTR, hOwner: UInt32, wszIssuanceLicense: win32more.Windows.Win32.Foundation.PWSTR, hBoundLicense: UInt32, phIssuanceLicense: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMAddRightWithUser(hIssuanceLicense: UInt32, hRight: UInt32, hUser: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMClearAllRights(hIssuanceLicense: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMSetMetaData(hIssuanceLicense: UInt32, wszContentId: win32more.Windows.Win32.Foundation.PWSTR, wszContentIdType: win32more.Windows.Win32.Foundation.PWSTR, wszSKUId: win32more.Windows.Win32.Foundation.PWSTR, wszSKUIdType: win32more.Windows.Win32.Foundation.PWSTR, wszContentType: win32more.Windows.Win32.Foundation.PWSTR, wszContentName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMSetUsagePolicy(hIssuanceLicense: UInt32, eUsagePolicyType: win32more.Windows.Win32.Data.RightsManagement.DRM_USAGEPOLICY_TYPE, fDelete: win32more.Windows.Win32.Foundation.BOOL, fExclusion: win32more.Windows.Win32.Foundation.BOOL, wszName: win32more.Windows.Win32.Foundation.PWSTR, wszMinVersion: win32more.Windows.Win32.Foundation.PWSTR, wszMaxVersion: win32more.Windows.Win32.Foundation.PWSTR, wszPublicKey: win32more.Windows.Win32.Foundation.PWSTR, wszDigestAlgorithm: win32more.Windows.Win32.Foundation.PWSTR, pbDigest: POINTER(Byte), cbDigest: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMSetRevocationPoint(hIssuanceLicense: UInt32, fDelete: win32more.Windows.Win32.Foundation.BOOL, wszId: win32more.Windows.Win32.Foundation.PWSTR, wszIdType: win32more.Windows.Win32.Foundation.PWSTR, wszURL: win32more.Windows.Win32.Foundation.PWSTR, pstFrequency: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), wszName: win32more.Windows.Win32.Foundation.PWSTR, wszPublicKey: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMSetApplicationSpecificData(hIssuanceLicense: UInt32, fDelete: win32more.Windows.Win32.Foundation.BOOL, wszName: win32more.Windows.Win32.Foundation.PWSTR, wszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMSetNameAndDescription(hIssuanceLicense: UInt32, fDelete: win32more.Windows.Win32.Foundation.BOOL, lcid: UInt32, wszName: win32more.Windows.Win32.Foundation.PWSTR, wszDescription: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMSetIntervalTime(hIssuanceLicense: UInt32, cDays: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetIssuanceLicenseTemplate(hIssuanceLicense: UInt32, puIssuanceLicenseTemplateLength: POINTER(UInt32), wszIssuanceLicenseTemplate: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetSignedIssuanceLicense(hEnv: UInt32, hIssuanceLicense: UInt32, uFlags: UInt32, pbSymKey: POINTER(Byte), cbSymKey: UInt32, wszSymKeyType: win32more.Windows.Win32.Foundation.PWSTR, wszClientLicensorCertificate: win32more.Windows.Win32.Foundation.PWSTR, pfnCallback: win32more.Windows.Win32.Data.RightsManagement.DRMCALLBACK, wszURL: win32more.Windows.Win32.Foundation.PWSTR, pvContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetSignedIssuanceLicenseEx(hEnv: UInt32, hIssuanceLicense: UInt32, uFlags: UInt32, pbSymKey: POINTER(Byte), cbSymKey: UInt32, wszSymKeyType: win32more.Windows.Win32.Foundation.PWSTR, pvReserved: VoidPtr, hEnablingPrincipal: UInt32, hBoundLicenseCLC: UInt32, pfnCallback: win32more.Windows.Win32.Data.RightsManagement.DRMCALLBACK, pvContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMClosePubHandle(hPub: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMDuplicatePubHandle(hPubIn: UInt32, phPubOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUserInfo(hUser: UInt32, puUserNameLength: POINTER(UInt32), wszUserName: win32more.Windows.Win32.Foundation.PWSTR, puUserIdLength: POINTER(UInt32), wszUserId: win32more.Windows.Win32.Foundation.PWSTR, puUserIdTypeLength: POINTER(UInt32), wszUserIdType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetRightInfo(hRight: UInt32, puRightNameLength: POINTER(UInt32), wszRightName: win32more.Windows.Win32.Foundation.PWSTR, pstFrom: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), pstUntil: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetRightExtendedInfo(hRight: UInt32, uIndex: UInt32, puExtendedInfoNameLength: POINTER(UInt32), wszExtendedInfoName: win32more.Windows.Win32.Foundation.PWSTR, puExtendedInfoValueLength: POINTER(UInt32), wszExtendedInfoValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUsers(hIssuanceLicense: UInt32, uIndex: UInt32, phUser: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUserRights(hIssuanceLicense: UInt32, hUser: UInt32, uIndex: UInt32, phRight: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetMetaData(hIssuanceLicense: UInt32, puContentIdLength: POINTER(UInt32), wszContentId: win32more.Windows.Win32.Foundation.PWSTR, puContentIdTypeLength: POINTER(UInt32), wszContentIdType: win32more.Windows.Win32.Foundation.PWSTR, puSKUIdLength: POINTER(UInt32), wszSKUId: win32more.Windows.Win32.Foundation.PWSTR, puSKUIdTypeLength: POINTER(UInt32), wszSKUIdType: win32more.Windows.Win32.Foundation.PWSTR, puContentTypeLength: POINTER(UInt32), wszContentType: win32more.Windows.Win32.Foundation.PWSTR, puContentNameLength: POINTER(UInt32), wszContentName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetApplicationSpecificData(hIssuanceLicense: UInt32, uIndex: UInt32, puNameLength: POINTER(UInt32), wszName: win32more.Windows.Win32.Foundation.PWSTR, puValueLength: POINTER(UInt32), wszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetIssuanceLicenseInfo(hIssuanceLicense: UInt32, pstTimeFrom: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), pstTimeUntil: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), uFlags: UInt32, puDistributionPointNameLength: POINTER(UInt32), wszDistributionPointName: win32more.Windows.Win32.Foundation.PWSTR, puDistributionPointURLLength: POINTER(UInt32), wszDistributionPointURL: win32more.Windows.Win32.Foundation.PWSTR, phOwner: POINTER(UInt32), pfOfficial: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetRevocationPoint(hIssuanceLicense: UInt32, puIdLength: POINTER(UInt32), wszId: win32more.Windows.Win32.Foundation.PWSTR, puIdTypeLength: POINTER(UInt32), wszIdType: win32more.Windows.Win32.Foundation.PWSTR, puURLLength: POINTER(UInt32), wszRL: win32more.Windows.Win32.Foundation.PWSTR, pstFrequency: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), puNameLength: POINTER(UInt32), wszName: win32more.Windows.Win32.Foundation.PWSTR, puPublicKeyLength: POINTER(UInt32), wszPublicKey: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetUsagePolicy(hIssuanceLicense: UInt32, uIndex: UInt32, peUsagePolicyType: POINTER(win32more.Windows.Win32.Data.RightsManagement.DRM_USAGEPOLICY_TYPE), pfExclusion: POINTER(win32more.Windows.Win32.Foundation.BOOL), puNameLength: POINTER(UInt32), wszName: win32more.Windows.Win32.Foundation.PWSTR, puMinVersionLength: POINTER(UInt32), wszMinVersion: win32more.Windows.Win32.Foundation.PWSTR, puMaxVersionLength: POINTER(UInt32), wszMaxVersion: win32more.Windows.Win32.Foundation.PWSTR, puPublicKeyLength: POINTER(UInt32), wszPublicKey: win32more.Windows.Win32.Foundation.PWSTR, puDigestAlgorithmLength: POINTER(UInt32), wszDigestAlgorithm: win32more.Windows.Win32.Foundation.PWSTR, pcbDigest: POINTER(UInt32), pbDigest: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetNameAndDescription(hIssuanceLicense: UInt32, uIndex: UInt32, pulcid: POINTER(UInt32), puNameLength: POINTER(UInt32), wszName: win32more.Windows.Win32.Foundation.PWSTR, puDescriptionLength: POINTER(UInt32), wszDescription: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetOwnerLicense(hIssuanceLicense: UInt32, puOwnerLicenseLength: POINTER(UInt32), wszOwnerLicense: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMGetIntervalTime(hIssuanceLicense: UInt32, pcDays: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMRepair() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMRegisterProtectedWindow(hEnv: UInt32, hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMIsWindowProtected(hwnd: win32more.Windows.Win32.Foundation.HWND, pfProtected: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('msdrm.dll')
def DRMAcquireIssuanceLicenseTemplate(hClient: UInt32, uFlags: UInt32, pvReserved: VoidPtr, cTemplates: UInt32, pwszTemplateIds: POINTER(win32more.Windows.Win32.Foundation.PWSTR), wszUrl: win32more.Windows.Win32.Foundation.PWSTR, pvContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DRMATTESTTYPE = Int32
DRMATTESTTYPE_FULLENVIRONMENT: win32more.Windows.Win32.Data.RightsManagement.DRMATTESTTYPE = 0
DRMATTESTTYPE_HASHONLY: win32more.Windows.Win32.Data.RightsManagement.DRMATTESTTYPE = 1
class DRMBOUNDLICENSEPARAMS(Structure):
    uVersion: UInt32
    hEnablingPrincipal: UInt32
    hSecureStore: UInt32
    wszRightsRequested: win32more.Windows.Win32.Foundation.PWSTR
    wszRightsGroup: win32more.Windows.Win32.Foundation.PWSTR
    idResource: win32more.Windows.Win32.Data.RightsManagement.DRMID
    cAuthenticatorCount: UInt32
    rghAuthenticators: POINTER(UInt32)
    wszDefaultEnablingPrincipalCredentials: win32more.Windows.Win32.Foundation.PWSTR
    dwFlags: UInt32
@winfunctype_pointer
def DRMCALLBACK(param0: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG, param1: win32more.Windows.Win32.Foundation.HRESULT, param2: VoidPtr, param3: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DRMENCODINGTYPE = Int32
DRMENCODINGTYPE_BASE64: win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE = 0
DRMENCODINGTYPE_STRING: win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE = 1
DRMENCODINGTYPE_LONG: win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE = 2
DRMENCODINGTYPE_TIME: win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE = 3
DRMENCODINGTYPE_UINT: win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE = 4
DRMENCODINGTYPE_RAW: win32more.Windows.Win32.Data.RightsManagement.DRMENCODINGTYPE = 5
DRMGLOBALOPTIONS = Int32
DRMGLOBALOPTIONS_USE_WINHTTP: win32more.Windows.Win32.Data.RightsManagement.DRMGLOBALOPTIONS = 0
DRMGLOBALOPTIONS_USE_SERVERSECURITYPROCESSOR: win32more.Windows.Win32.Data.RightsManagement.DRMGLOBALOPTIONS = 1
class DRMID(Structure):
    uVersion: UInt32
    wszIDType: win32more.Windows.Win32.Foundation.PWSTR
    wszID: win32more.Windows.Win32.Foundation.PWSTR
DRMSECURITYPROVIDERTYPE = Int32
DRMSECURITYPROVIDERTYPE_SOFTWARESECREP: win32more.Windows.Win32.Data.RightsManagement.DRMSECURITYPROVIDERTYPE = 0
DRMSPECTYPE = Int32
DRMSPECTYPE_UNKNOWN: win32more.Windows.Win32.Data.RightsManagement.DRMSPECTYPE = 0
DRMSPECTYPE_FILENAME: win32more.Windows.Win32.Data.RightsManagement.DRMSPECTYPE = 1
DRMTIMETYPE = Int32
DRMTIMETYPE_SYSTEMUTC: win32more.Windows.Win32.Data.RightsManagement.DRMTIMETYPE = 0
DRMTIMETYPE_SYSTEMLOCAL: win32more.Windows.Win32.Data.RightsManagement.DRMTIMETYPE = 1
class DRM_ACTSERV_INFO(Structure):
    uVersion: UInt32
    wszPubKey: win32more.Windows.Win32.Foundation.PWSTR
    wszURL: win32more.Windows.Win32.Foundation.PWSTR
class DRM_CLIENT_VERSION_INFO(Structure):
    uStructVersion: UInt32
    dwVersion: UInt32 * 4
    wszHierarchy: Char * 256
    wszProductId: Char * 256
    wszProductDescription: Char * 256
DRM_DISTRIBUTION_POINT_INFO = Int32
DRM_DISTRIBUTION_POINT_LICENSE_ACQUISITION: win32more.Windows.Win32.Data.RightsManagement.DRM_DISTRIBUTION_POINT_INFO = 0
DRM_DISTRIBUTION_POINT_PUBLISHING: win32more.Windows.Win32.Data.RightsManagement.DRM_DISTRIBUTION_POINT_INFO = 1
DRM_DISTRIBUTION_POINT_REFERRAL_INFO: win32more.Windows.Win32.Data.RightsManagement.DRM_DISTRIBUTION_POINT_INFO = 2
class DRM_LICENSE_ACQ_DATA(Structure):
    uVersion: UInt32
    wszURL: win32more.Windows.Win32.Foundation.PWSTR
    wszLocalFilename: win32more.Windows.Win32.Foundation.PWSTR
    pbPostData: POINTER(Byte)
    dwPostDataSize: UInt32
    wszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
DRM_STATUS_MSG = Int32
DRM_MSG_ACTIVATE_MACHINE: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 0
DRM_MSG_ACTIVATE_GROUPIDENTITY: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 1
DRM_MSG_ACQUIRE_LICENSE: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 2
DRM_MSG_ACQUIRE_ADVISORY: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 3
DRM_MSG_SIGN_ISSUANCE_LICENSE: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 4
DRM_MSG_ACQUIRE_CLIENTLICENSOR: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 5
DRM_MSG_ACQUIRE_ISSUANCE_LICENSE_TEMPLATE: win32more.Windows.Win32.Data.RightsManagement.DRM_STATUS_MSG = 6
DRM_USAGEPOLICY_TYPE = Int32
DRM_USAGEPOLICY_TYPE_BYNAME: win32more.Windows.Win32.Data.RightsManagement.DRM_USAGEPOLICY_TYPE = 0
DRM_USAGEPOLICY_TYPE_BYPUBLICKEY: win32more.Windows.Win32.Data.RightsManagement.DRM_USAGEPOLICY_TYPE = 1
DRM_USAGEPOLICY_TYPE_BYDIGEST: win32more.Windows.Win32.Data.RightsManagement.DRM_USAGEPOLICY_TYPE = 2
DRM_USAGEPOLICY_TYPE_OSEXCLUSION: win32more.Windows.Win32.Data.RightsManagement.DRM_USAGEPOLICY_TYPE = 3


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Phone.PersonalInformation
import win32more.Windows.Phone.PersonalInformation.Provisioning
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class ContactPartnerProvisioningManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.Provisioning.ContactPartnerProvisioningManager'
    @winrt_classmethod
    def AssociateNetworkAccountAsync(cls: win32more.Windows.Phone.PersonalInformation.Provisioning.IContactPartnerProvisioningManagerStatics, store: win32more.Windows.Phone.PersonalInformation.ContactStore, networkName: WinRT_String, networkAccountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def ImportVcardToSystemAsync(cls: win32more.Windows.Phone.PersonalInformation.Provisioning.IContactPartnerProvisioningManagerStatics, stream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def AssociateSocialNetworkAccountAsync(cls: win32more.Windows.Phone.PersonalInformation.Provisioning.IContactPartnerProvisioningManagerStatics2, store: win32more.Windows.Phone.PersonalInformation.ContactStore, networkName: WinRT_String, networkAccountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IContactPartnerProvisioningManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.Provisioning.IContactPartnerProvisioningManagerStatics'
    _iid_ = Guid('{c0d79a21-01af-4fd3-98cd-b3d656de15f4}')
    @winrt_commethod(6)
    def AssociateNetworkAccountAsync(self, store: win32more.Windows.Phone.PersonalInformation.ContactStore, networkName: WinRT_String, networkAccountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ImportVcardToSystemAsync(self, stream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
class IContactPartnerProvisioningManagerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.Provisioning.IContactPartnerProvisioningManagerStatics2'
    _iid_ = Guid('{c26155f7-55ed-475d-9334-c5d484c30f1a}')
    @winrt_commethod(6)
    def AssociateSocialNetworkAccountAsync(self, store: win32more.Windows.Phone.PersonalInformation.ContactStore, networkName: WinRT_String, networkAccountId: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IMessagePartnerProvisioningManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.Provisioning.IMessagePartnerProvisioningManagerStatics'
    _iid_ = Guid('{8a1b0850-73c5-457c-bc59-ed7d615c05a4}')
    @winrt_commethod(6)
    def ImportSmsToSystemAsync(self, incoming: Boolean, read: Boolean, body: WinRT_String, sender: WinRT_String, recipients: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], deliveryTime: win32more.Windows.Foundation.DateTime) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ImportMmsToSystemAsync(self, incoming: Boolean, read: Boolean, subject: WinRT_String, sender: WinRT_String, recipients: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], deliveryTime: win32more.Windows.Foundation.DateTime, attachments: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]) -> win32more.Windows.Foundation.IAsyncAction: ...
class MessagePartnerProvisioningManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.Provisioning.MessagePartnerProvisioningManager'
    @winrt_classmethod
    def ImportSmsToSystemAsync(cls: win32more.Windows.Phone.PersonalInformation.Provisioning.IMessagePartnerProvisioningManagerStatics, incoming: Boolean, read: Boolean, body: WinRT_String, sender: WinRT_String, recipients: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], deliveryTime: win32more.Windows.Foundation.DateTime) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def ImportMmsToSystemAsync(cls: win32more.Windows.Phone.PersonalInformation.Provisioning.IMessagePartnerProvisioningManagerStatics, incoming: Boolean, read: Boolean, subject: WinRT_String, sender: WinRT_String, recipients: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], deliveryTime: win32more.Windows.Foundation.DateTime, attachments: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]) -> win32more.Windows.Foundation.IAsyncAction: ...


make_ready(__name__)
